@@ -21,6 +21,7 @@ from horizon import exceptions
 from horizon.utils.memoized import memoized
 from openstack_dashboard.api import base
 
+from magnumclient.common import utils as client_utils
 from magnumclient.v1 import certificates
 from magnumclient.v1 import client as magnum_client
 from magnumclient.v1 import cluster_templates
@@ -34,6 +35,7 @@ CLUSTER_CREATE_ATTRS = clusters.CREATION_ATTRIBUTES
 CERTIFICATE_CREATE_ATTRS = certificates.CREATION_ATTRIBUTES
 QUOTA_CREATION_ATTRIBUTES = quotas.CREATION_ATTRIBUTES
 CLUSTER_UPDATE_ALLOWED_PROPERTIES = set(['/node_count'])
+DEFAULT_API_VERSION = '1.10'
 
 
 def _cleanup_params(attrs, create, **params):
@@ -119,7 +121,9 @@ def magnumclient(request):
     insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
     cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
     openstack_api_versions = getattr(settings, 'OPENSTACK_API_VERSIONS', {})
-    magnum_api_version = openstack_api_versions.get(service_type, 1.1)
+    magnum_api_version = openstack_api_versions.get(service_type,
+                                                    DEFAULT_API_VERSION)
+    LOG.debug('Using magnum_api_version = %s.' % magnum_api_version)
 
     c = magnum_client.Client(username=request.user.username,
                              project_id=request.user.tenant_id,
@@ -194,6 +198,32 @@ def cluster_show(request, id):
     return magnumclient(request).clusters.get(id)
 
 
+def cluster_config(request, id):
+    cluster = magnumclient(request).clusters.get(id)
+    if (hasattr(cluster, 'api_address') and cluster.api_address is None):
+        LOG.debug(f"api_address for cluster {id} is not known yet.")
+    cluster_template = magnumclient(request).cluster_templates.get(
+        cluster.cluster_template_id
+    )
+
+    opts = {
+        'cluster_uuid': cluster.uuid,
+    }
+    tls = {}
+    if not cluster_template.tls_disabled:
+        tls = client_utils.generate_csr_and_key()
+        tls["ca"] = magnumclient(request).certificates.get(**opts).pem
+        opts["csr"] = tls.pop("csr")
+        tls["cert"] = magnumclient(request).certificates.create(**opts).pem
+
+    config = client_utils.config_cluster(
+        cluster, cluster_template, cfg_dir="", direct_output=True
+    )
+    result = {"cluster_config": config}
+    result.update(tls)
+    return result
+
+
 def cluster_resize(request, cluster_id, node_count,
                    nodes_to_remove=None, nodegroup=None):
 
@@ -259,3 +289,8 @@ def quotas_update(request, project_id, resource, **kwargs):
 
 def quotas_delete(request, project_id, resource):
     return magnumclient(request).quotas.delete(project_id, resource)
+
+
+def nodegroup_list(request, cluster_id=None, limit=None, marker=None):
+    return magnumclient(request).nodegroups.list(cluster_id, limit=limit,
+                                                 marker=marker)
