@@ -350,7 +350,8 @@
                           type: 'select',
                           titleMap: [
                             {value: "devicemapper", name: gettext("Device Mapper")},
-                            {value: "overlay", name: gettext("Overlay")}
+                            {value: "overlay", name: gettext("Overlay")},
+                            {value: "overlay2", name: gettext("Overlay2")}
                           ]
                         }
                       ]
@@ -493,7 +494,7 @@
         fixed_subnet: "",
         dns_nameserver: "",
         master_lb_enabled: "",
-        floating_ip_enabled: "",
+        floating_ip_enabled: true,
         labels: ""
       };
 
